@@ -25,7 +25,7 @@ from sbi.inference.snle.snle_a import SNLE_A
 from sbi.inference.snpe.snpe_b import SNPE_B
 from sbi.inference.snpe.snpe_c import SNPE_C  # noqa: F401
 from sbi.inference.snre import SNRE, SNRE_A, SNRE_B  # noqa: F401
-from sbi.user_input.user_input_checks import prepare_for_sbi
+from sbi.utils.user_input_checks import prepare_for_sbi
 
 SNL = SNLE = SNLE_A
 _snle_family = ["SNL"]
