@@ -10,6 +10,7 @@ from warnings import warn
 
 import torch
 from torch import Tensor
+from torch.utils import data
 from torch.utils.tensorboard import SummaryWriter
 
 import sbi.inference
@@ -18,9 +19,9 @@ from sbi.simulators.simutils import simulate_in_batches
 from sbi.utils import (
     get_log_root,
     handle_invalid_x,
+    warn_if_zscoring_changes_data,
     warn_on_invalid_x,
     warn_on_invalid_x_for_snpec_leakage,
-    warn_if_zscoring_changes_data,
 )
 from sbi.utils.sbiutils import get_simulations_since_round
 from sbi.utils.torchutils import process_device
@@ -275,6 +276,73 @@ class NeuralInference(ABC):
     ) -> NeuralPosterior:
         raise NotImplementedError
 
+    def get_dataloaders(
+        self,
+        dataset: data.TensorDataset,
+        training_batch_size: int = 50,
+        validation_fraction: float = 0.1,
+        resume_training: bool = False,
+        dataloader_kwargs: Optional[dict] = None,
+    ) -> Tuple[data.DataLoader, data.DataLoader]:
+        """Return dataloaders for training and validation.
+
+        Args:
+            dataset: holding all theta and x, optionally masks.
+            training_batch_size: training arg of inference methods.
+            resume_training: Whether the current call is resuming training so that no
+                new training and validation indices into the dataset have to be created.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
+
+        Returns:
+            Tuple of dataloaders for training and validation.
+
+        """
+
+        # Get total number of training examples.
+        num_examples = len(dataset)
+
+        # Select random train and validation splits from (theta, x) pairs.
+        num_training_examples = int((1 - validation_fraction) * num_examples)
+        num_validation_examples = num_examples - num_training_examples
+
+        if not resume_training:
+            permuted_indices = torch.randperm(num_examples)
+            self.train_indices, self.val_indices = (
+                permuted_indices[:num_training_examples],
+                permuted_indices[num_training_examples:],
+            )
+
+        # Create training and validation loaders using a subset sampler.
+        # Intentionally use dicts to define the default dataloader args
+        # Then, use dataloader_kwargs to override (or add to) any of these defaults
+        # https://stackoverflow.com/questions/44784577/in-method-call-args-how-to-override-keyword-argument-of-unpacked-dict
+        train_loader_kwargs = {
+            "batch_size": min(training_batch_size, num_training_examples),
+            "drop_last": True,
+            "sampler": data.sampler.SubsetRandomSampler(self.train_indices),
+        }
+        train_loader_kwargs = (
+            dict(train_loader_kwargs, **dataloader_kwargs)
+            if dataloader_kwargs is not None
+            else train_loader_kwargs
+        )
+        val_loader_kwargs = {
+            "batch_size": min(training_batch_size, num_validation_examples),
+            "shuffle": False,
+            "drop_last": True,
+            "sampler": data.sampler.SubsetRandomSampler(self.val_indices),
+        }
+        val_loader_kwargs = (
+            dict(val_loader_kwargs, **dataloader_kwargs)
+            if dataloader_kwargs is not None
+            else val_loader_kwargs
+        )
+        train_loader = data.DataLoader(dataset, **train_loader_kwargs)
+        val_loader = data.DataLoader(dataset, **val_loader_kwargs)
+
+        return train_loader, val_loader
+
     def _converged(self, epoch: int, stop_after_epochs: int) -> bool:
         """Return whether the training converged yet and save best model state so far.
 
