@@ -158,6 +158,7 @@ class DirectPosterior(NeuralPosterior):
         x: Optional[Tensor] = None,
         norm_posterior: bool = True,
         track_gradients: bool = False,
+        leakage_correction_params: Optional[dict] = None,
     ) -> Tensor:
         r"""
         Returns the log-probability of the posterior $p(\theta|x).$
@@ -176,6 +177,11 @@ class DirectPosterior(NeuralPosterior):
             track_gradients: Whether the returned tensor supports tracking gradients.
                 This can be helpful for e.g. sensitivity analysis, but increases memory
                 consumption.
+            leakage_correction_params: A `dict` of keyword arguments to override the
+                default values of `leakage_correction()`. Possible options are:
+                `num_rejection_samples`, `force_update`, `show_progress_bars`, and
+                `rejection_sampling_batch_size`.
+                These parameters only have an effect if `norm_posterior=True`.
 
         Returns:
             `(len(θ),)`-shaped log posterior probability $\log p(\theta|x)$ for θ in the
@@ -204,8 +210,14 @@ class DirectPosterior(NeuralPosterior):
                 torch.tensor(float("-inf"), dtype=torch.float32),
             )
 
+            if leakage_correction_params is None:
+                leakage_correction_params = dict()  # use defaults
             log_factor = (
-                log(self.leakage_correction(x=batched_first_of_batch(x)))
+                log(
+                    self.leakage_correction(
+                        x=batched_first_of_batch(x), **leakage_correction_params
+                    )
+                )
                 if norm_posterior
                 else 0
             )
