@@ -1,13 +1,7 @@
 # This file is part of sbi, a toolkit for simulation-based inference. sbi is licensed
 # under the Affero General Public License v3, see <https://www.gnu.org/licenses/>.
 
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    List,
-    Optional,
-)
+from typing import Any, Callable, Dict, List, Optional, Union
 from warnings import warn
 
 import numpy as np
@@ -17,11 +11,7 @@ from torch import Tensor, nn
 from sbi.inference.posteriors.base_posterior import NeuralPosterior
 from sbi.types import Shape
 from sbi.utils import del_entries
-from sbi.utils.torchutils import (
-    ScalarFloat,
-    ensure_theta_batched,
-    ensure_x_batched,
-)
+from sbi.utils.torchutils import ScalarFloat, ensure_theta_batched, ensure_x_batched
 
 
 class RatioBasedPosterior(NeuralPosterior):
@@ -72,7 +62,10 @@ class RatioBasedPosterior(NeuralPosterior):
         super().__init__(**kwargs)
 
     def log_prob(
-        self, theta: Tensor, x: Optional[Tensor] = None, track_gradients: bool = False,
+        self,
+        theta: Tensor,
+        x: Optional[Tensor] = None,
+        track_gradients: bool = False,
     ) -> Tensor:
         r"""
         Returns the log-probability of $p(x|\theta) \cdot p(\theta).$
@@ -83,9 +76,8 @@ class RatioBasedPosterior(NeuralPosterior):
 
         Args:
             theta: Parameters $\theta$.
-            x: Conditioning context for posterior $p(\theta|x)$. If not provided, fall
-                back onto an `x_o` if previously provided for multi-round training, or
-                to another default if set later for convenience, see `.set_default_x()`.
+            x: Conditioning context for posterior $p(\theta|x)$. If not provided,
+                fall back onto `x` passed to `set_default_x()`.
             track_gradients: Whether the returned tensor supports tracking gradients.
                 This can be helpful for e.g. sensitivity analysis, but increases memory
                 consumption.
@@ -105,7 +97,7 @@ class RatioBasedPosterior(NeuralPosterior):
         with torch.set_grad_enabled(track_gradients):
             # Send to device for evaluation, send to CPU for comparison with prior.
             log_ratio = (
-                self.net(torch.cat((theta.to(self._device), x.to(self._device)), dim=1))
+                self.net([theta.to(self._device), x.to(self._device)])
                 .reshape(-1)
                 .to("cpu")
             )
@@ -141,8 +133,7 @@ class RatioBasedPosterior(NeuralPosterior):
                 sample_shape is multidimensional we simply draw `sample_shape.numel()`
                 samples and then reshape into the desired shape.
             x: Conditioning context for posterior $p(\theta|x)$. If not provided,
-                fall back onto `x_o` if previously provided for multiround training, or
-                to a set default (see `set_default_x()` method).
+                fall back onto `x` passed to `set_default_x()`.
             show_progress_bars: Whether to show sampling progress monitor.
             sample_with_mcmc: Optional parameter to override `self.sample_with_mcmc`.
             mcmc_method: Optional parameter to override `self.mcmc_method`.
@@ -214,8 +205,7 @@ class RatioBasedPosterior(NeuralPosterior):
                 specified in `dims_to_sample` will be fixed to values given in
                 `condition`.
             x: Conditioning context for posterior $p(\theta|x)$. If not provided,
-                fall back onto `x_o` if previously provided for multiround training, or
-                to a set default (see `set_default_x()` method).
+                fall back onto `x` passed to `set_default_x()`.
             show_progress_bars: Whether to show sampling progress monitor.
             mcmc_method: Optional parameter to override `self.mcmc_method`.
             mcmc_parameters: Dictionary overriding the default parameters for MCMC.
@@ -242,6 +232,71 @@ class RatioBasedPosterior(NeuralPosterior):
             mcmc_parameters,
         )
 
+    def map(
+        self,
+        x: Optional[Tensor] = None,
+        num_iter: int = 1000,
+        learning_rate: float = 1e-2,
+        init_method: Union[str, Tensor] = "posterior",
+        num_init_samples: int = 500,
+        num_to_optimize: int = 100,
+        save_best_every: int = 10,
+        show_progress_bars: bool = True,
+    ) -> Tensor:
+        """
+        Returns the maximum-a-posteriori estimate (MAP).
+
+        The method can be interrupted (Ctrl-C) when the user sees that the
+        log-probability converges. The best estimate will be saved in `self.map_`.
+
+        The MAP is obtained by running gradient ascent from a given number of starting
+        positions (samples from the posterior with the highest log-probability). After
+        the optimization is done, we select the parameter set that has the highest
+        log-probability after the optimization.
+
+        Warning: The default values used by this function are not well-tested. They
+        might require hand-tuning for the problem at hand.
+
+        Args:
+            x: Conditioning context for posterior $p(\theta|x)$. If not provided,
+                fall back onto `x` passed to `set_default_x()`.
+            num_iter: Maximum Number of optimization steps that the algorithm takes
+                to find the MAP.
+            early_stop_at: If `None`, it will optimize for `max_num_iter` iterations.
+                If `float`, the optimization will stop as soon as the steps taken by
+                the optimizer are smaller than `early_stop_at` times the standard
+                deviation of the initial guesses.
+            learning_rate: Learning rate of the optimizer.
+            init_method: How to select the starting parameters for the optimization. If
+                it is a string, it can be either [`posterior`, `prior`], which samples
+                the respective distribution `num_init_samples` times. If it is a,
+                the tensor will be used as init locations.
+            num_init_samples: Draw this number of samples from the posterior and
+                evaluate the log-probability of all of them.
+            num_to_optimize: From the drawn `num_init_samples`, use the
+                `num_to_optimize` with highest log-probability as the initial points
+                for the optimization.
+            save_best_every: The best log-probability is computed, saved in the
+                `map`-attribute, and printed every `print_best_every`-th iteration.
+                Computing the best log-probability creates a significant overhead
+                (thus, the default is `10`.)
+            show_progress_bars: Whether or not to show a progressbar for sampling from
+                the posterior.
+
+        Returns:
+            The MAP estimate.
+        """
+        return super().map(
+            x=x,
+            num_iter=num_iter,
+            learning_rate=learning_rate,
+            init_method=init_method,
+            num_init_samples=num_init_samples,
+            num_to_optimize=num_to_optimize,
+            save_best_every=save_best_every,
+            show_progress_bars=show_progress_bars,
+        )
+
     @property
     def _num_trained_rounds(self) -> int:
         return self._trained_rounds
@@ -290,7 +345,11 @@ class PotentialFunctionProvider:
     """
 
     def __call__(
-        self, prior, classifier: nn.Module, x: Tensor, mcmc_method: str,
+        self,
+        prior,
+        classifier: nn.Module,
+        x: Tensor,
+        mcmc_method: str,
     ) -> Callable:
         r"""Return potential function for posterior $p(\theta|x)$.
 
@@ -334,15 +393,9 @@ class PotentialFunctionProvider:
             num_batch, *(1 for _ in range(x_batched.ndim - 1))
         )
 
-        assert (
-            x_batched.ndim == 2
-        ), """X must not be multidimensional for ratio-based methods because it will be
-              concatenated with theta."""
         with torch.set_grad_enabled(False):
             log_ratio = (
-                self.classifier(torch.cat((theta.to(self.x.device), x_repeated), dim=1))
-                .reshape(-1)
-                .cpu()
+                self.classifier([theta.to(self.x.device), x_repeated]).reshape(-1).cpu()
             )
 
         # Notice opposite sign to pyro potential.
@@ -366,8 +419,6 @@ class PotentialFunctionProvider:
         theta = ensure_theta_batched(theta)
         x = ensure_x_batched(self.x)
 
-        log_ratio = self.classifier(
-            torch.cat((theta.to(x.device), x), dim=1).reshape(1, -1)
-        ).cpu()
+        log_ratio = self.classifier([theta.to(x.device), x]).cpu()
 
         return -(log_ratio + self.prior.log_prob(theta))
