@@ -127,6 +127,7 @@ class LikelihoodEstimator(NeuralInference, ABC):
         discard_prior_samples: bool = False,
         retrain_from_scratch_each_round: bool = False,
         show_train_summary: bool = False,
+        dataloader_kwargs: Optional[Dict] = None,
     ) -> LikelihoodBasedPosterior:
         r"""
         Train the density estimator to learn the distribution $p(x|\theta)$.
@@ -145,6 +146,8 @@ class LikelihoodEstimator(NeuralInference, ABC):
                 estimator for the posterior from scratch each round.
             show_train_summary: Whether to print the number of epochs and validation
                 loss after the training.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
 
         Returns:
             Density estimator that has learned the distribution $p(x|\theta)$.
@@ -152,44 +155,23 @@ class LikelihoodEstimator(NeuralInference, ABC):
 
         max_num_epochs = 2 ** 31 - 1 if max_num_epochs is None else max_num_epochs
 
-        # Load data from most recent round.
-        self._round = max(self._data_round_index)
-        theta, x, _ = self.get_simulations(self._round, exclude_invalid_x, False)
-
         # Starting index for the training set (1 = discard round-0 samples).
         start_idx = int(discard_prior_samples and self._round > 0)
-        theta, x, _ = self.get_simulations(start_idx, exclude_invalid_x)
-
-        # Get total number of training examples.
-        num_examples = len(theta)
-
-        # Select random train and validation splits from (theta, x) pairs.
-        num_training_examples = int((1 - validation_fraction) * num_examples)
-        num_validation_examples = num_examples - num_training_examples
-
-        if not resume_training:
-            permuted_indices = torch.randperm(num_examples)
-            self.train_indices, self.val_indices = (
-                permuted_indices[:num_training_examples],
-                permuted_indices[num_training_examples:],
-            )
+        # Load data from most recent round.
+        self._round = max(self._data_round_index)
+        theta, x, _ = self.get_simulations(
+            start_idx, exclude_invalid_x, warn_on_invalid=True
+        )
 
         # Dataset is shared for training and validation loaders.
         dataset = data.TensorDataset(theta, x)
 
-        # Create neural net and validation loaders using a subset sampler.
-        train_loader = data.DataLoader(
+        train_loader, val_loader = self.get_dataloaders(
             dataset,
-            batch_size=min(training_batch_size, num_training_examples),
-            drop_last=True,
-            sampler=SubsetRandomSampler(self.train_indices),
-        )
-        val_loader = data.DataLoader(
-            dataset,
-            batch_size=min(training_batch_size, num_validation_examples),
-            shuffle=False,
-            drop_last=False,
-            sampler=SubsetRandomSampler(self.val_indices),
+            training_batch_size,
+            validation_fraction,
+            resume_training,
+            dataloader_kwargs=dataloader_kwargs,
         )
 
         # First round or if retraining from scratch:
@@ -251,7 +233,10 @@ class LikelihoodEstimator(NeuralInference, ABC):
                     # Evaluate on x with theta as context.
                     log_prob = self._neural_net.log_prob(x_batch, context=theta_batch)
                     log_prob_sum += log_prob.sum().item()
-            self._val_log_prob = log_prob_sum / num_validation_examples
+            # Take mean over all validation samples.
+            self._val_log_prob = log_prob_sum / (
+                len(val_loader) * val_loader.batch_size
+            )
             # Log validation log prob for every epoch.
             self._summary["validation_log_probs"].append(self._val_log_prob)
 
