@@ -167,6 +167,7 @@ class PosteriorEstimator(NeuralInference, ABC):
         discard_prior_samples: bool = False,
         retrain_from_scratch_each_round: bool = False,
         show_train_summary: bool = False,
+        dataloader_kwargs: Optional[dict] = None,
     ) -> DirectPosterior:
         r"""
         Return density estimator that approximates the distribution $p(\theta|x)$.
@@ -197,6 +198,8 @@ class PosteriorEstimator(NeuralInference, ABC):
                 estimator for the posterior from scratch each round.
             show_train_summary: Whether to print the number of epochs and validation
                 loss after the training.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
 
         Returns:
             Density estimator that approximates the distribution $p(\theta|x)$.
@@ -208,9 +211,6 @@ class PosteriorEstimator(NeuralInference, ABC):
 
         max_num_epochs = 2 ** 31 - 1 if max_num_epochs is None else max_num_epochs
 
-        # Load data from most recent round.
-        theta, x, _ = self.get_simulations(self._round, exclude_invalid_x, False)
-
         # Starting index for the training set (1 = discard round-0 samples).
         start_idx = int(discard_prior_samples and self._round > 0)
 
@@ -218,25 +218,9 @@ class PosteriorEstimator(NeuralInference, ABC):
         if self.use_non_atomic_loss:
             start_idx = self._round
 
-        theta, x, prior_masks = self.get_simulations(start_idx, exclude_invalid_x)
-
-        # Set the proposal to the last proposal that was passed by the user. For
-        # atomic SNPE, it does not matter what the proposal is. For non-atomic
-        # SNPE, we only use the latest data that was passed, i.e. the one from the
-        # last proposal.
-        proposal = self._proposal_roundwise[-1]
-
-        # Select random neural net and validation splits from (theta, x) pairs.
-        num_total_examples = len(theta)
-        num_training_examples = int((1 - validation_fraction) * num_total_examples)
-        num_validation_examples = num_total_examples - num_training_examples
-
-        if not resume_training:
-            permuted_indices = torch.randperm(num_total_examples)
-            self.train_indices, self.val_indices = (
-                permuted_indices[:num_training_examples],
-                permuted_indices[num_training_examples:],
-            )
+        theta, x, prior_masks = self.get_simulations(
+            start_idx, exclude_invalid_x, warn_on_invalid=True
+        )
 
         # Dataset is shared for training and validation loaders.
         dataset = data.TensorDataset(
@@ -245,19 +229,18 @@ class PosteriorEstimator(NeuralInference, ABC):
             prior_masks,
         )
 
-        # Create neural net and validation loaders using a subset sampler.
-        train_loader = data.DataLoader(
+        # Set the proposal to the last proposal that was passed by the user. For
+        # atomic SNPE, it does not matter what the proposal is. For non-atomic
+        # SNPE, we only use the latest data that was passed, i.e. the one from the
+        # last proposal.
+        proposal = self._proposal_roundwise[-1]
+
+        train_loader, val_loader = self.get_dataloaders(
             dataset,
-            batch_size=min(training_batch_size, num_training_examples),
-            drop_last=True,
-            sampler=SubsetRandomSampler(self.train_indices),
-        )
-        val_loader = data.DataLoader(
-            dataset,
-            batch_size=min(training_batch_size, num_validation_examples),
-            shuffle=False,
-            drop_last=True,
-            sampler=SubsetRandomSampler(self.val_indices),
+            training_batch_size,
+            validation_fraction,
+            resume_training,
+            dataloader_kwargs=dataloader_kwargs,
         )
 
         # First round or if retraining from scratch:
@@ -336,7 +319,10 @@ class PosteriorEstimator(NeuralInference, ABC):
                     )
                     log_prob_sum += batch_log_prob.sum().item()
 
-            self._val_log_prob = log_prob_sum / num_validation_examples
+            # Take mean over all validation samples.
+            self._val_log_prob = log_prob_sum / (
+                len(val_loader) * val_loader.batch_size
+            )
             # Log validation log prob for every epoch.
             self._summary["validation_log_probs"].append(self._val_log_prob)
 
