@@ -106,6 +106,7 @@ class SNPE_C(PosteriorEstimator):
         use_combined_loss: bool = False,
         retrain_from_scratch_each_round: bool = False,
         show_train_summary: bool = False,
+        dataloader_kwargs: Optional[Dict] = None,
     ) -> DirectPosterior:
         r"""
         Return density estimator that approximates the distribution $p(\theta|x)$.
@@ -141,6 +142,8 @@ class SNPE_C(PosteriorEstimator):
                 estimator for the posterior from scratch each round.
             show_train_summary: Whether to print the number of epochs and validation
                 loss and leakage after the training.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
 
         Returns:
             Density estimator that approximates the distribution $p(\theta|x)$.
