@@ -66,6 +66,7 @@ class SNRE_B(RatioEstimator):
         discard_prior_samples: bool = False,
         retrain_from_scratch_each_round: bool = False,
         show_train_summary: bool = False,
+        dataloader_kwargs: Optional[Dict] = None,
     ) -> NeuralPosterior:
         r"""
         Return classifier that approximates the ratio $p(\theta,x)/p(\theta)p(x)$.
@@ -95,6 +96,8 @@ class SNRE_B(RatioEstimator):
                 estimator for the posterior from scratch each round.
             show_train_summary: Whether to print the number of epochs and validation
                 loss and leakage after the training.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
 
         Returns:
             Classifier that approximates the ratio $p(\theta,x)/p(\theta)p(x)$.
