@@ -130,6 +130,7 @@ class RatioEstimator(NeuralInference, ABC):
         discard_prior_samples: bool = False,
         retrain_from_scratch_each_round: bool = False,
         show_train_summary: bool = False,
+        dataloader_kwargs: Optional[Dict] = None,
     ) -> RatioBasedPosterior:
         r"""
         Return classifier that approximates the ratio $p(\theta,x)/p(\theta)p(x)$.
@@ -147,6 +148,8 @@ class RatioEstimator(NeuralInference, ABC):
                 samples.
             retrain_from_scratch_each_round: Whether to retrain the conditional density
                 estimator for the posterior from scratch each round.
+            dataloader_kwargs: Additional or updated kwargs to be passed to the training
+                and validation dataloaders (like, e.g., a collate_fn)
 
         Returns:
             Classifier that approximates the ratio $p(\theta,x)/p(\theta)p(x)$.
@@ -154,50 +157,29 @@ class RatioEstimator(NeuralInference, ABC):
 
         max_num_epochs = 2 ** 31 - 1 if max_num_epochs is None else max_num_epochs
 
-        # Load data from most recent round.
-        self._round = max(self._data_round_index)
-        theta, x, _ = self.get_simulations(self._round, exclude_invalid_x, False)
-
         # Starting index for the training set (1 = discard round-0 samples).
         start_idx = int(discard_prior_samples and self._round > 0)
-        theta, x, _ = self.get_simulations(start_idx, exclude_invalid_x)
-
-        # Get total number of training examples.
-        num_examples = len(theta)
-
-        # Select random train and validation splits from (theta, x) pairs.
-        num_training_examples = int((1 - validation_fraction) * num_examples)
-        num_validation_examples = num_examples - num_training_examples
-
-        if not resume_training:
-            permuted_indices = torch.randperm(num_examples)
-            self.train_indices, self.val_indices = (
-                permuted_indices[:num_training_examples],
-                permuted_indices[num_training_examples:],
-            )
-
-        clipped_batch_size = min(training_batch_size, num_validation_examples)
-
-        num_atoms = clamp_and_warn(
-            "num_atoms", num_atoms, min_val=2, max_val=clipped_batch_size
+        # Load data from most recent round.
+        self._round = max(self._data_round_index)
+        theta, x, _ = self.get_simulations(
+            start_idx, exclude_invalid_x, warn_on_invalid=True
         )
 
         # Dataset is shared for training and validation loaders.
         dataset = data.TensorDataset(theta, x)
 
-        # Create neural net and validation loaders using a subset sampler.
-        train_loader = data.DataLoader(
+        train_loader, val_loader = self.get_dataloaders(
             dataset,
-            batch_size=clipped_batch_size,
-            drop_last=True,
-            sampler=SubsetRandomSampler(self.train_indices),
+            training_batch_size,
+            validation_fraction,
+            resume_training,
+            dataloader_kwargs=dataloader_kwargs,
         )
-        val_loader = data.DataLoader(
-            dataset,
-            batch_size=clipped_batch_size,
-            shuffle=False,
-            drop_last=False,
-            sampler=SubsetRandomSampler(self.val_indices),
+
+        clipped_batch_size = min(training_batch_size, len(val_loader))
+
+        num_atoms = clamp_and_warn(
+            "num_atoms", num_atoms, min_val=2, max_val=clipped_batch_size
         )
 
         # First round or if retraining from scratch:
@@ -245,16 +227,19 @@ class RatioEstimator(NeuralInference, ABC):
 
             # Calculate validation performance.
             self._neural_net.eval()
-            log_prob_sum = 0
+            loss_sum = 0
             with torch.no_grad():
                 for batch in val_loader:
                     theta_batch, x_batch = (
                         batch[0].to(self._device),
                         batch[1].to(self._device),
                     )
-                    log_prob = self._loss(theta_batch, x_batch, num_atoms)
-                    log_prob_sum -= log_prob.sum().item()
-                self._val_log_prob = log_prob_sum / num_validation_examples
+                    loss = self._loss(theta_batch, x_batch, num_atoms)
+                    loss_sum -= loss.sum().item()
+                # Take mean over all validation samples.
+                self._val_log_prob = loss_sum / (
+                    len(val_loader) * val_loader.batch_size
+                )
                 # Log validation log prob for every epoch.
                 self._summary["validation_log_probs"].append(self._val_log_prob)
 
