@@ -205,7 +205,10 @@ def gaussian_kde_log_eval(samples, query):
 
 class BoxUniform(Independent):
     def __init__(
-        self, low: ScalarFloat, high: ScalarFloat, reinterpreted_batch_ndims: int = 1,
+        self,
+        low: ScalarFloat,
+        high: ScalarFloat,
+        reinterpreted_batch_ndims: int = 1,
     ):
         """Multidimensional uniform distribution defined on a box.
 
@@ -230,6 +233,7 @@ class BoxUniform(Independent):
             Uniform(
                 low=torch.as_tensor(low, dtype=torch.float32),
                 high=torch.as_tensor(high, dtype=torch.float32),
+                validate_args=False,
             ),
             reinterpreted_batch_ndims,
         )
