@@ -136,6 +136,10 @@ def process_pytorch_prior(prior: Distribution) -> Tuple[Distribution, int, bool]
         prior_returns_numpy: False.
     """
 
+    # Turn off validation of input arguments to allow `log_prob()` on samples outside
+    # of the support.
+    prior.set_default_validate_args(False)
+
     # Reject unwrapped scalar priors.
     # This will reject Uniform priors with dimension larger than 1.
     if prior.sample().ndim == 0:
@@ -154,7 +158,9 @@ def process_pytorch_prior(prior: Distribution) -> Tuple[Distribution, int, bool]
     check_prior_batch_dims(prior)
 
     if not prior.sample().dtype == float32:
-        prior = PytorchReturnTypeWrapper(prior, return_type=float32)
+        prior = PytorchReturnTypeWrapper(
+            prior, return_type=float32, validate_args=False
+        )
 
     # This will fail for float64 priors.
     check_prior_return_type(prior)
@@ -345,7 +351,9 @@ def check_prior_batch_behavior(prior) -> None:
 
 
 def process_simulator(
-    user_simulator: Callable, prior, is_numpy_simulator: bool,
+    user_simulator: Callable,
+    prior,
+    is_numpy_simulator: bool,
 ) -> Callable:
     """Return a simulator that meets the requirements for usage in sbi.
 
@@ -449,7 +457,10 @@ def process_x(x: Tensor, x_shape: torch.Size) -> Tensor:
     return x
 
 
-def prepare_for_sbi(simulator: Callable, prior,) -> Tuple[Callable, Distribution]:
+def prepare_for_sbi(
+    simulator: Callable,
+    prior,
+) -> Tuple[Callable, Distribution]:
     """Prepare simulator, prior and for usage in sbi.
 
     One of the goals is to allow you to use sbi with inputs computed in numpy.
