@@ -36,10 +36,30 @@ def test_handle_invalid_x(x_shape, set_seed):
     assert torch.isfinite(x[x_is_valid]).all()
 
 
+def test_z_scoring_warning():
+
+    # Create data with large variance.
+    num_dim = 2
+    theta = torch.ones(100, num_dim)
+    x = torch.rand(100, num_dim)
+    x[:50] += 1e7
+
+    # Make sure a warning is raised because z-scoring will map these data to duplicate
+    # data points.
+    with pytest.warns(UserWarning, match="Z-scoring these simulation outputs"):
+        SNPE_C(utils.BoxUniform(zeros(num_dim), ones(num_dim))).append_simulations(
+            theta, x
+        ).train(max_num_epochs=1)
+
+
 @pytest.mark.slow
 @pytest.mark.parametrize(
     ("method", "exclude_invalid_x", "percent_nans"),
-    ((SNPE_C, True, 0.05), (SNL, True, 0.05), (SRE, True, 0.05),),
+    (
+        (SNPE_C, True, 0.05),
+        (SNL, True, 0.05),
+        (SRE, True, 0.05),
+    ),
 )
 def test_inference_with_nan_simulator(
     method, exclude_invalid_x, percent_nans, set_seed
@@ -87,7 +107,7 @@ def test_inference_with_nan_simulator(
 
 
 @pytest.mark.slow
-def test_inference_with_rejection_estimator(set_seed):
+def test_inference_with_restriction_estimator(set_seed):
 
     # likelihood_mean will be likelihood_shift+theta
     num_dim = 3
@@ -95,7 +115,6 @@ def test_inference_with_rejection_estimator(set_seed):
     likelihood_cov = 0.3 * eye(num_dim)
     x_o = zeros(1, num_dim)
     num_samples = 500
-    num_simulations = 2000
 
     def linear_gaussian_nan(
         theta, likelihood_shift=likelihood_shift, likelihood_cov=likelihood_cov
@@ -121,7 +140,7 @@ def test_inference_with_rejection_estimator(set_seed):
     num_rounds = 2
 
     for r in range(num_rounds):
-        theta, x = simulate_for_sbi(simulator, proposals[-1], 500)
+        theta, x = simulate_for_sbi(simulator, proposals[-1], 1000)
         rejection_estimator.append_simulations(theta, x)
         if r < num_rounds - 1:
             _ = rejection_estimator.train()
