@@ -37,7 +37,10 @@ def test_api_snl_on_linearGaussian(num_dim: int, set_seed):
     prior = MultivariateNormal(loc=prior_mean, covariance_matrix=prior_cov)
 
     simulator, prior = prepare_for_sbi(diagonal_linear_gaussian, prior)
-    inference = SNL(prior, show_progress_bars=False,)
+    inference = SNL(
+        prior,
+        show_progress_bars=False,
+    )
 
     theta, x = simulate_for_sbi(simulator, prior, 1000, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train(max_num_epochs=5)
@@ -86,7 +89,10 @@ def test_c2st_snl_on_linearGaussian_different_dims(set_seed):
     )
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    inference = SNL(prior, show_progress_bars=False,)
+    inference = SNL(
+        prior,
+        show_progress_bars=False,
+    )
 
     theta, x = simulate_for_sbi(
         simulator, prior, num_simulations, simulation_batch_size=50
@@ -135,7 +141,10 @@ def test_c2st_snl_on_linearGaussian(num_dim: int, prior_str: str, set_seed):
     simulator = lambda theta: linear_gaussian(theta, likelihood_shift, likelihood_cov)
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    inference = SNL(prior, show_progress_bars=False,)
+    inference = SNL(
+        prior,
+        show_progress_bars=False,
+    )
 
     theta, x = simulate_for_sbi(simulator, prior, 1000, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train()
@@ -189,7 +198,10 @@ def test_c2st_multi_round_snl_on_linearGaussian(set_seed):
     simulator = lambda theta: linear_gaussian(theta, likelihood_shift, likelihood_cov)
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    inference = SNL(prior, show_progress_bars=False,)
+    inference = SNL(
+        prior,
+        show_progress_bars=False,
+    )
 
     theta, x = simulate_for_sbi(simulator, prior, 750, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train()
@@ -209,7 +221,11 @@ def test_c2st_multi_round_snl_on_linearGaussian(set_seed):
 
 @pytest.mark.slow
 @pytest.mark.parametrize(
-    "mcmc_method, prior_str", (("slice", "gaussian"), ("slice", "uniform"),),
+    "mcmc_method, prior_str",
+    (
+        ("slice", "gaussian"),
+        ("slice", "uniform"),
+    ),
 )
 def test_api_snl_sampling_methods(mcmc_method: str, prior_str: str, set_seed):
     """Runs SNL on linear Gaussian and tests sampling from posterior via mcmc.
@@ -230,7 +246,10 @@ def test_api_snl_sampling_methods(mcmc_method: str, prior_str: str, set_seed):
         prior = utils.BoxUniform(-1.0 * ones(num_dim), ones(num_dim))
 
     simulator, prior = prepare_for_sbi(diagonal_linear_gaussian, prior)
-    inference = SNL(prior, show_progress_bars=False,)
+    inference = SNL(
+        prior,
+        show_progress_bars=False,
+    )
 
     theta, x = simulate_for_sbi(simulator, prior, 200, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train(max_num_epochs=5)
