@@ -37,11 +37,7 @@ def test_api_sre_on_linearGaussian(num_dim: int):
     prior = MultivariateNormal(loc=zeros(num_dim), covariance_matrix=eye(num_dim))
 
     simulator, prior = prepare_for_sbi(diagonal_linear_gaussian, prior)
-    inference = SRE(
-        prior,
-        classifier="resnet",
-        show_progress_bars=False,
-    )
+    inference = SRE(prior, classifier="resnet", show_progress_bars=False,)
 
     theta, x = simulate_for_sbi(simulator, prior, 1000, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train(max_num_epochs=5)
@@ -91,11 +87,7 @@ def test_c2st_sre_on_linearGaussian_different_dims(set_seed):
         )
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    inference = SRE(
-        prior,
-        classifier="resnet",
-        show_progress_bars=False,
-    )
+    inference = SRE(prior, classifier="resnet", show_progress_bars=False,)
 
     theta, x = simulate_for_sbi(simulator, prior, 5000, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train()
@@ -117,10 +109,7 @@ def test_c2st_sre_on_linearGaussian_different_dims(set_seed):
     ),
 )
 def test_c2st_sre_on_linearGaussian(
-    num_dim: int,
-    prior_str: str,
-    method_str: str,
-    set_seed,
+    num_dim: int, prior_str: str, method_str: str, set_seed,
 ):
     """Test c2st accuracy of inference with SRE on linear Gaussian model.
 
@@ -132,6 +121,7 @@ def test_c2st_sre_on_linearGaussian(
 
     x_o = zeros(1, num_dim)
     num_samples = 500
+    num_simulations = 2500
 
     # `likelihood_mean` will be `likelihood_shift + theta`.
     likelihood_shift = -1.0 * ones(num_dim)
@@ -155,16 +145,14 @@ def test_c2st_sre_on_linearGaussian(
         return linear_gaussian(theta, likelihood_shift, likelihood_cov)
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    kwargs = dict(
-        prior=prior,
-        classifier="resnet",
-        show_progress_bars=False,
-    )
+    kwargs = dict(prior=prior, classifier="resnet", show_progress_bars=False,)
 
     inference = SRE(**kwargs) if method_str == "sre" else AALR(**kwargs)
 
     # Should use default `num_atoms=10` for SRE; `num_atoms=2` for AALR
-    theta, x = simulate_for_sbi(simulator, prior, 1000, simulation_batch_size=50)
+    theta, x = simulate_for_sbi(
+        simulator, prior, num_simulations, simulation_batch_size=50
+    )
     _ = inference.append_simulations(theta, x).train()
     posterior = inference.build_posterior().set_default_x(x_o)
 
@@ -231,11 +219,7 @@ def test_api_sre_sampling_methods(mcmc_method: str, prior_str: str, set_seed):
         prior = utils.BoxUniform(low=-1.0 * ones(num_dim), high=ones(num_dim))
 
     simulator, prior = prepare_for_sbi(diagonal_linear_gaussian, prior)
-    inference = SRE(
-        prior,
-        classifier="resnet",
-        show_progress_bars=False,
-    )
+    inference = SRE(prior, classifier="resnet", show_progress_bars=False,)
 
     theta, x = simulate_for_sbi(simulator, prior, 200, simulation_batch_size=50)
     _ = inference.append_simulations(theta, x).train(max_num_epochs=5)
